
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.008.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.4229"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Namespace for packages that can make files persistent",
  "dist_author" => [
    "Patrick Hochstenbach, C<< <patrick.hochstenbach at ugent.be> >>"
  ],
  "dist_name" => "Catmandu-FileStore",
  "dist_version" => "1.16",
  "license" => "perl",
  "module_name" => "Catmandu::FileStore",
  "recommends" => {
    "Log::Any::Adapter::Log4perl" => "0.06",
    "Log::Log4perl" => "1.44"
  },
  "recursive_test_files" => 1,
  "requires" => {
    "Catmandu" => "1.06",
    "Clone" => 0,
    "Hash::Merge::Simple" => 0,
    "IO::String" => 0,
    "Module::Build" => "0.4229",
    "Moo" => 0,
    "Moo::Role" => 0,
    "Package::Stash" => 0,
    "Path::Iterator::Rule" => 0,
    "Path::Tiny" => 0,
    "URI::Escape" => 0,
    "namespace::clean" => 0,
    "perl" => "v5.10.1"
  },
  "test_requires" => {
    "App::Cmd::Tester::CaptureExternal" => 0,
    "Cpanel::JSON::XS" => 0,
    "IO::Callback" => 0,
    "Log::Any::Adapter::Log4perl" => 0,
    "Log::Any::Test" => "1.03",
    "Log::Log4perl" => 0,
    "Role::Tiny" => 0,
    "Test::Deep" => "0.112",
    "Test::Exception" => "0.43",
    "Test::LWP::UserAgent" => 0,
    "Test::More" => "0.99",
    "Test::Pod" => 0
  }
);


my %fallback_build_requires = (
  "App::Cmd::Tester::CaptureExternal" => 0,
  "Cpanel::JSON::XS" => 0,
  "IO::Callback" => 0,
  "Log::Any::Adapter::Log4perl" => 0,
  "Log::Any::Test" => "1.03",
  "Log::Log4perl" => 0,
  "Module::Build" => "0.4229",
  "Role::Tiny" => 0,
  "Test::Deep" => "0.112",
  "Test::Exception" => "0.43",
  "Test::LWP::UserAgent" => 0,
  "Test::More" => "0.99",
  "Test::Pod" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
